# Generated by roxygen2: do not edit by hand

S3method("$",RLum.Analysis)
S3method("$",RLum.Data.Curve)
S3method("$",RLum.Results)
S3method("$<-",DRAC.list)
S3method("*",RLum.Data.Curve)
S3method("*",RLum.Data.Spectrum)
S3method("+",RLum.Data.Curve)
S3method("+",RLum.Data.Spectrum)
S3method("-",RLum.Data.Curve)
S3method("-",RLum.Data.Spectrum)
S3method("/",RLum.Data.Curve)
S3method("/",RLum.Data.Spectrum)
S3method("[",RLum.Analysis)
S3method("[",RLum.Data.Curve)
S3method("[",RLum.Data.Image)
S3method("[",RLum.Data.Spectrum)
S3method("[",RLum.Results)
S3method("[<-",DRAC.list)
S3method("[<-",RLum.Data.Curve)
S3method("[[",RLum.Analysis)
S3method("[[",RLum.Results)
S3method("[[<-",DRAC.list)
S3method(as.data.frame,DRAC.list)
S3method(as.data.frame,RLum.Data.Curve)
S3method(as.data.frame,RLum.Data.Spectrum)
S3method(as.data.frame,Risoe.BINfileData)
S3method(as.list,RLum.Analysis)
S3method(as.list,RLum.Data.Curve)
S3method(as.list,RLum.Data.Image)
S3method(as.list,RLum.Data.Spectrum)
S3method(as.list,RLum.Results)
S3method(as.matrix,RLum.Data.Curve)
S3method(as.matrix,RLum.Data.Image)
S3method(as.matrix,RLum.Data.Spectrum)
S3method(bin,RLum.Data.Curve)
S3method(bin,RLum.Data.Spectrum)
S3method(dim,RLum.Data.Curve)
S3method(dim,RLum.Data.Spectrum)
S3method(hist,RLum.Analysis)
S3method(hist,RLum.Data.Curve)
S3method(hist,RLum.Data.Image)
S3method(hist,RLum.Results)
S3method(length,RLum.Analysis)
S3method(length,RLum.Data.Curve)
S3method(length,RLum.Results)
S3method(length,Risoe.BINfileData)
S3method(merge,RLum)
S3method(names,RLum.Analysis)
S3method(names,RLum.Data.Curve)
S3method(names,RLum.Data.Image)
S3method(names,RLum.Data.Spectrum)
S3method(names,RLum.Results)
S3method(names,Risoe.BINfileData)
S3method(plot,RLum.Analysis)
S3method(plot,RLum.Data.Curve)
S3method(plot,RLum.Data.Image)
S3method(plot,RLum.Data.Spectrum)
S3method(plot,RLum.Results)
S3method(plot,Risoe.BINfileData)
S3method(plot,list)
S3method(print,DRAC.highlights)
S3method(print,DRAC.list)
S3method(rep,RLum)
S3method(row.names,RLum.Data.Spectrum)
S3method(subset,RLum.Analysis)
S3method(subset,Risoe.BINfileData)
S3method(summary,RLum.Analysis)
S3method(summary,RLum.Data.Curve)
S3method(summary,RLum.Data.Image)
S3method(summary,RLum.Results)
S3method(unlist,RLum.Analysis)
export("add_metadata<-")
export("rename_metadata<-")
export("replace_metadata<-")
export(.as.latex.table)
export(Risoe.BINfileData2RLum.Analysis)
export(analyse_Al2O3C_CrossTalk)
export(analyse_Al2O3C_ITC)
export(analyse_Al2O3C_Measurement)
export(analyse_FadingMeasurement)
export(analyse_IRSAR.RF)
export(analyse_SAR.CWOSL)
export(analyse_SAR.TL)
export(analyse_baSAR)
export(analyse_pIRIRSequence)
export(analyse_portableOSL)
export(apply_CosmicRayRemoval)
export(apply_Crosstalk)
export(apply_EfficiencyCorrection)
export(bin)
export(bin_RLum.Data)
export(calc_AliquotSize)
export(calc_AverageDose)
export(calc_CentralDose)
export(calc_CobbleDoseRate)
export(calc_CommonDose)
export(calc_CosmicDoseRate)
export(calc_EED_Model)
export(calc_FadingCorr)
export(calc_FastRatio)
export(calc_FiniteMixture)
export(calc_FuchsLang2001)
export(calc_HomogeneityTest)
export(calc_Huntley2006)
export(calc_IEU)
export(calc_Lamothe2003)
export(calc_MaxDose)
export(calc_MinDose)
export(calc_MoransI)
export(calc_OSLLxTxDecomposed)
export(calc_OSLLxTxRatio)
export(calc_SourceDoseRate)
export(calc_Statistics)
export(calc_TLLxTxRatio)
export(calc_ThermalLifetime)
export(calc_WodaFuchs2008)
export(calc_gSGC)
export(calc_gSGC_feldspar)
export(combine_De_Dr)
export(convert_Activity2Concentration)
export(convert_BIN2CSV)
export(convert_CW2pHMi)
export(convert_CW2pLM)
export(convert_CW2pLMi)
export(convert_CW2pPMi)
export(convert_Concentration2DoseRate)
export(convert_Daybreak2CSV)
export(convert_PSL2CSV)
export(convert_PSL2Risoe.BINfileData)
export(convert_RLum2Risoe.BINfileData)
export(convert_SG2MG)
export(convert_Second2Gray)
export(convert_Wavelength2Energy)
export(convert_XSYG2CSV)
export(correct_PMTLinearity)
export(extract_IrradiationTimes)
export(extract_ROI)
export(fit_CWCurve)
export(fit_DoseResponseCurve)
export(fit_EmissionSpectra)
export(fit_LMCurve)
export(fit_OSLLifeTimes)
export(fit_SurfaceExposure)
export(fit_ThermalQuenching)
export(get_Layout)
export(get_RLum)
export(get_rightAnswer)
export(import_Data)
export(length_RLum)
export(melt_RLum)
export(merge_RLum)
export(merge_RLum.Analysis)
export(merge_RLum.Data.Curve)
export(merge_RLum.Data.Spectrum)
export(merge_RLum.Results)
export(merge_Risoe.BINfileData)
export(names_RLum)
export(normalise_RLum)
export(plot_AbanicoPlot)
export(plot_DRCSummary)
export(plot_DRTResults)
export(plot_DetPlot)
export(plot_DoseResponseCurve)
export(plot_FilterCombinations)
export(plot_GrowthCurve)
export(plot_Histogram)
export(plot_KDE)
export(plot_MoranScatterplot)
export(plot_NRt)
export(plot_OSLAgeSummary)
export(plot_RLum)
export(plot_RLum.Analysis)
export(plot_RLum.Data.Curve)
export(plot_RLum.Data.Image)
export(plot_RLum.Data.Spectrum)
export(plot_RLum.Results)
export(plot_ROI)
export(plot_RadialPlot)
export(plot_Risoe.BINfileData)
export(plot_SingleGrainDisc)
export(plot_ViolinPlot)
export(read_BIN2R)
export(read_BINXLOG2R)
export(read_Daybreak2R)
export(read_HeliosOSL2R)
export(read_PSL2R)
export(read_RF2R)
export(read_SPE2R)
export(read_TIFF2R)
export(read_XSYG2R)
export(remove_RLum)
export(remove_SignalBackground)
export(replicate_RLum)
export(report_RLum)
export(sTeve)
export(scale_GammaDose)
export(set_RLum)
export(set_Risoe.BINfileData)
export(smooth_RLum)
export(sort_RLum)
export(structure_RLum)
export(subset_SingleGrainData)
export(template_DRAC)
export(trim_RLum.Data)
export(tune_Data)
export(use_DRAC)
export(verify_SingleGrainData)
export(view)
export(write_R2BIN)
export(write_R2TIFF)
export(write_RLum2CSV)
exportClasses(RLum)
exportClasses(RLum.Analysis)
exportClasses(RLum.Data)
exportClasses(RLum.Data.Curve)
exportClasses(RLum.Data.Image)
exportClasses(RLum.Data.Spectrum)
exportClasses(RLum.Results)
exportClasses(Risoe.BINfileData)
exportMethods("add_metadata<-")
exportMethods("rename_metadata<-")
exportMethods("replace_metadata<-")
exportMethods(bin_RLum.Data)
exportMethods(get_RLum)
exportMethods(length_RLum)
exportMethods(melt_RLum)
exportMethods(names_RLum)
exportMethods(normalise_RLum)
exportMethods(remove_RLum)
exportMethods(replicate_RLum)
exportMethods(set_RLum)
exportMethods(set_Risoe.BINfileData)
exportMethods(show)
exportMethods(smooth_RLum)
exportMethods(sort_RLum)
exportMethods(structure_RLum)
exportMethods(view)
import(data.table)
import(methods)
import(utils)
importFrom(Rcpp,evalCpp)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,curve)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,approx)
importFrom(stats,coef)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,median)
importFrom(stats,na.exclude)
importFrom(stats,nls)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,uniroot)
useDynLib(Luminescence, .registration = TRUE)
