#' Function to get the right answer
#'
#' This function returns just the right answer
#'
#' @param ... you can pass an infinite number of further arguments
#'
#' @return Returns the right answer
#'
#' @section Function version: 0.1.0
#'
#' @author inspired by R.G.
#'
#' @examples
#'
#' ## you really want to know?
#' get_rightAnswer()
#'
#' @export
get_rightAnswer <- function(...) {
  return(46)
}
