% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_Risoe.BINfileData.R
\name{get_Risoe.BINfileData}
\alias{get_Risoe.BINfileData}
\title{General accessor function for RLum S4 class objects}
\usage{
get_Risoe.BINfileData(object, ...)
}
\arguments{
\item{object}{\linkS4class{Risoe.BINfileData} (\strong{required}):
S4 object of class \code{RLum}}

\item{...}{further arguments that one might want to pass to the specific
get function}
}
\value{
Return is the same as input objects as provided in the list
}
\description{
Function calls object-specific get functions for RisoeBINfileData S4 class objects.
}
\details{
The function provides a generalised access point for specific
\linkS4class{Risoe.BINfileData} objects. \cr
Depending on the input object, the corresponding get function will be selected.
Allowed arguments can be found in the documentations of the corresponding
\linkS4class{Risoe.BINfileData} class.
}
\section{Function version}{
 0.1.0
}

\seealso{
\linkS4class{Risoe.BINfileData}
}
\author{
Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
, RLum Developer Team} 

\section{How to cite}{
Kreutzer, S., 2023. get_Risoe.BINfileData(): General accessor function for RLum S4 class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., 2023. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 0.9.21. https://CRAN.R-project.org/package=Luminescence
}

\keyword{utilities}
