% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/merge_RLum.Analysis.R
\name{merge_RLum.Analysis}
\alias{merge_RLum.Analysis}
\title{Merge function for RLum.Analysis S4 class objects}
\usage{
merge_RLum.Analysis(objects)
}
\arguments{
\item{objects}{\link{list} of \linkS4class{RLum.Analysis} (\strong{required}):
list of S4 objects of class \code{RLum.Analysis}. Furthermore other objects of
class \linkS4class{RLum} can be added, see details.}
}
\value{
Returns an \linkS4class{RLum.Analysis} object ordered according to the order
provided with the input list.
}
\description{
This function simply allows to merge \linkS4class{RLum.Analysis}
objects. Moreover, other \linkS4class{RLum.Data} objects can be added
to an existing \linkS4class{RLum.Analysis} object. Supported objects
to be added are: \linkS4class{RLum.Data.Curve},
\linkS4class{RLum.Data.Spectrum} and
\linkS4class{RLum.Data.Image}.
}
\note{
The information for the slot 'protocol' is taken from the first
\linkS4class{RLum.Analysis} object in the input list. Therefore at
least one object of type \linkS4class{RLum.Analysis} has to be provided.
}
\section{Function version}{
 0.2.1
}

\examples{

##merge different RLum objects from the example data
data(ExampleData.RLum.Analysis, envir = environment())
data(ExampleData.BINfileData, envir = environment())

object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
curve <- get_RLum(object)[[2]]

temp.merged <- merge_RLum.Analysis(list(curve, IRSAR.RF.Data, IRSAR.RF.Data))

}
\seealso{
\link{merge_RLum}, \linkS4class{RLum.Analysis},
\linkS4class{RLum.Data.Curve},
\linkS4class{RLum.Data.Spectrum},
\linkS4class{RLum.Data.Image}, \linkS4class{RLum}
}
\author{
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
, RLum Developer Team} 

\section{How to cite}{
Kreutzer, S., 2026. merge_RLum.Analysis(): Merge function for RLum.Analysis S4 class objects. Function version 0.2.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.1. https://r-lum.github.io/Luminescence/
}

\keyword{internal}
\keyword{utilities}
